Behaviours: supervisor.
| start_link/3 | Starts the supervisor with a specific filter name, handler module, and port. |
| stop/1 | Stops the supervisor and its children. |
start_link(FilterName, HandlerModule, Port) -> any()
Starts the supervisor with a specific filter name, handler module, and port.
stop(SupName) -> any()
Stops the supervisor and its children.
Generated by EDoc